==> zio-aws-efs_2.12-5.17.121.3-sources.jar: zio/aws/efs/model/DestinationToCreate.scala <==
package zio.aws.efs.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.efs.model.primitives.{KmsKeyId, AvailabilityZoneName, RegionName}
import scala.jdk.CollectionConverters._
final case class DestinationToCreate(
    region: Option[RegionName] = None,
    availabilityZoneName: Option[AvailabilityZoneName] = None,
    kmsKeyId: Option[KmsKeyId] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.efs.model.DestinationToCreate = {
    import DestinationToCreate.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.efs.model.DestinationToCreate
      .builder()
      .optionallyWith(
        region.map(value => RegionName.unwrap(value): java.lang.String)
      )(_.region)
      .optionallyWith(
        availabilityZoneName.map(value =>
          AvailabilityZoneName.unwrap(value): java.lang.String
        )
      )(_.availabilityZoneName)
      .optionallyWith(
        kmsKeyId.map(value => KmsKeyId.unwrap(value): java.lang.String)
      )(_.kmsKeyId)
      .build()
  }
  def asReadOnly: zio.aws.efs.model.DestinationToCreate.ReadOnly =
    zio.aws.efs.model.DestinationToCreate.wrap(buildAwsValue())
}
object DestinationToCreate {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.efs.model.DestinationToCreate
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.efs.model.DestinationToCreate =
      zio.aws.efs.model.DestinationToCreate(
        region.map(value => value),
        availabilityZoneName.map(value => value),
        kmsKeyId.map(value => value)
      )
    def region: Option[RegionName]
    def availabilityZoneName: Option[AvailabilityZoneName]
    def kmsKeyId: Option[KmsKeyId]
    def getRegion: ZIO[Any, AwsError, RegionName] =
      AwsError.unwrapOptionField("region", region)
    def getAvailabilityZoneName: ZIO[Any, AwsError, AvailabilityZoneName] =
      AwsError.unwrapOptionField("availabilityZoneName", availabilityZoneName)
    def getKmsKeyId: ZIO[Any, AwsError, KmsKeyId] =
      AwsError.unwrapOptionField("kmsKeyId", kmsKeyId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.efs.model.DestinationToCreate
  ) extends zio.aws.efs.model.DestinationToCreate.ReadOnly {
    override val region: Option[RegionName] = scala
      .Option(impl.region())
      .map(value => zio.aws.efs.model.primitives.RegionName(value))
    override val availabilityZoneName: Option[AvailabilityZoneName] = scala
      .Option(impl.availabilityZoneName())
      .map(value => zio.aws.efs.model.primitives.AvailabilityZoneName(value))
    override val kmsKeyId: Option[KmsKeyId] = scala
      .Option(impl.kmsKeyId())
      .map(value => zio.aws.efs.model.primitives.KmsKeyId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.efs.model.DestinationToCreate
  ): zio.aws.efs.model.DestinationToCreate.ReadOnly = new Wrapper(impl)
}

==> zio-aws-efs_2.12-5.20.37.1-sources.jar: zio/aws/efs/model/DestinationToCreate.scala <==
package zio.aws.efs.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.efs.model.primitives.{KmsKeyId, AvailabilityZoneName, RegionName}
import scala.jdk.CollectionConverters._
final case class DestinationToCreate(
    region: Optional[RegionName] = Optional.Absent,
    availabilityZoneName: Optional[AvailabilityZoneName] = Optional.Absent,
    kmsKeyId: Optional[KmsKeyId] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.efs.model.DestinationToCreate = {
    import DestinationToCreate.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.efs.model.DestinationToCreate
      .builder()
      .optionallyWith(
        region.map(value => RegionName.unwrap(value): java.lang.String)
      )(_.region)
      .optionallyWith(
        availabilityZoneName.map(value =>
          AvailabilityZoneName.unwrap(value): java.lang.String
        )
      )(_.availabilityZoneName)
      .optionallyWith(
        kmsKeyId.map(value => KmsKeyId.unwrap(value): java.lang.String)
      )(_.kmsKeyId)
      .build()
  }
  def asReadOnly: zio.aws.efs.model.DestinationToCreate.ReadOnly =
    zio.aws.efs.model.DestinationToCreate.wrap(buildAwsValue())
}
object DestinationToCreate {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.efs.model.DestinationToCreate
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.efs.model.DestinationToCreate =
      zio.aws.efs.model.DestinationToCreate(
        region.map(value => value),
        availabilityZoneName.map(value => value),
        kmsKeyId.map(value => value)
      )
    def region: Optional[RegionName]
    def availabilityZoneName: Optional[AvailabilityZoneName]
    def kmsKeyId: Optional[KmsKeyId]
    def getRegion: ZIO[Any, AwsError, RegionName] =
      AwsError.unwrapOptionField("region", region)
    def getAvailabilityZoneName: ZIO[Any, AwsError, AvailabilityZoneName] =
      AwsError.unwrapOptionField("availabilityZoneName", availabilityZoneName)
    def getKmsKeyId: ZIO[Any, AwsError, KmsKeyId] =
      AwsError.unwrapOptionField("kmsKeyId", kmsKeyId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.efs.model.DestinationToCreate
  ) extends zio.aws.efs.model.DestinationToCreate.ReadOnly {
    override val region: Optional[RegionName] = zio.aws.core.internal
      .optionalFromNullable(impl.region())
      .map(value => zio.aws.efs.model.primitives.RegionName(value))
    override val availabilityZoneName: Optional[AvailabilityZoneName] =
      zio.aws.core.internal
        .optionalFromNullable(impl.availabilityZoneName())
        .map(value => zio.aws.efs.model.primitives.AvailabilityZoneName(value))
    override val kmsKeyId: Optional[KmsKeyId] = zio.aws.core.internal
      .optionalFromNullable(impl.kmsKeyId())
      .map(value => zio.aws.efs.model.primitives.KmsKeyId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.efs.model.DestinationToCreate
  ): zio.aws.efs.model.DestinationToCreate.ReadOnly = new Wrapper(impl)
}
